@@ -150,16 +150,16 @@ main(int argc, char *argv[])
 	    if (comm && strcmp(comm, task->comm) != 0)
 		continue;
 	    if (!all)
-		show_inode(task, task->fs->root, -1);
-	    show_inode(task, task->fs->pwd, -2);
+		show_inode(task, task->fs[0].root, -1);
+	    show_inode(task, task->fs[0].pwd, -2);
 	    show_inode(task, task->executable, -3);
-	    for (vmm = task->mm->mmap; vmm; vmm = vm.vm_next) {
+	    for (vmm = task->mm[0].mmap; vmm; vmm = vm.vm_next) {
 		kmemread(&vm, (unsigned long) vmm, sizeof vm);
 		if (vm.vm_inode)
 		    show_inode(task, vm.vm_inode, -4);
 	    }
 	    for (i = 0; i < NR_OPEN; ++i) {
-		if ((tmp = task->files->fd[i])) {
+		if ((tmp = task->files[0].fd[i])) {
 		    if (mmap_page((unsigned long) tmp) < 0 && verbose)
 			    printf("mmap_page failed\n");
 		    filep = KPTR(tmp);
@@ -250,9 +250,9 @@ show_inode(struct task_struct *task, struct inode *ino, int type)
 	    _read_pipe_fops = k_addr("_read_pipe_fops");
 	    _write_pipe_fops = k_addr("_write_pipe_fops");
 	}
-	if ((long)((struct file *)KPTR(task->files->fd[type]))->f_op == _read_pipe_fops)
+	if ((long)((struct file *)KPTR(task->files[0].fd[type]))->f_op == _read_pipe_fops)
 	    rw = "<-";
-	else if ((long)((struct file *)KPTR(task->files->fd[type]))->f_op == _write_pipe_fops)
+	else if ((long)((struct file *)KPTR(task->files[0].fd[type]))->f_op == _write_pipe_fops)
 	    rw = "->";
 	printf("* (pipe %s %#lx %d %dr %dw)\n",
 	       rw, (unsigned long) PIPE_BASE(*inop),
@@ -366,17 +366,16 @@ lookup_filename(int ino, int dev)
 #include <linux/net.h>
 #include <netinet/in.h>
 #include <sys/un.h>
-#include <linux/ddi.h>
 #include <linux/timer.h>
 #include <linux/ip.h>
 #include <linux/tcp.h>
-#include <net/inet/inet.h>
-#include <net/inet/dev.h>
+#include <linux/inet.h>
+#include <linux/netdevice.h>
 #include <net/inet/protocol.h>
 #include <net/inet/sock.h>
 #include <net/inet/ip.h>
 #include <net/inet/tcp.h>
-#include <net/unix/unix.h>
+#include <net/unix/unix.h> 
 
 #ifndef SOCK_INODE
 #define	SOCK_INODE(x)	((x)->dummy)
