@@ -37,13 +37,14 @@ extern caddr_t kbase;
 #define	SSIZE(stack)	(KSTK_ESP(stack) ? _SSIZE(stack) : 0)
 
 #define	VSIZE(task,stack) ((task)->pid == 0 ? 0 : \
-			  (((task)->mm->brk + 1023 + SSIZE(stack)) / 1024))
+			  (((task)->mm[0].brk + 1023 + SSIZE(stack)) / 1024))
 #define	SIZE(task,stack)  ((task)->pid == 0 ? 0 : \
-			  (((task)->mm->brk - (task)->mm->end_code + 1023 + \
+			  (((task)->mm[0].brk - (task)->mm[0].end_code + 1023 + \
 			  SSIZE(stack)) / 1024))
 
-#define TASK_TTY(task)	(major((task)->tty) != 0 \
-			? (task)->tty : makedev(4, (task)->tty))
+#define TASK_TTY(task)	((task)->tty == NULL ? -1 : ( \
+			major(tty_kmemread ((task)->tty)) != 0 \
+			? tty_kmemread ((task)->tty) : makedev(4, tty_kmemread ((task)->tty) )))
 
 typedef unsigned reg_t;
 
@@ -74,9 +75,10 @@ void *xmalloc(int size);
 void read_globals(void);
 int tty_to_dev(char *tty);
 char *dev_to_tty(int dev);
-int tty_pgrp(int tty);
+int tty_pgrp(int tty,struct tty_struct *);
 char *user_from_uid(int uid);
 int kmemread(void *buf, unsigned long addr, int size);
+int tty_kmemread(struct tty_struct *);
 int mmap_init(void);
 int mmap_page(unsigned long addr);
 void get_memmap(void);
