@@ -28,7 +28,7 @@ status(struct task_struct *task)
 	*p++ = 'I';
     else
 	*p++ = "RSDZTP" [task->state];
-    if (task->mm->rss == 0 && task->state != TASK_ZOMBIE && task->pid != 0)
+    if (task->mm[0].rss == 0 && task->state != TASK_ZOMBIE && task->pid != 0)
 	*p++ = 'W';
     if (task->priority > PZERO)
 	*p++ = '<';
@@ -38,7 +38,7 @@ status(struct task_struct *task)
 	*p++ = ((task->flags & PF_TRACESYS) ? 'X' : 'x');
     if (task->leader)
 	*p++ = 's';
-    if (TASK_TTY(task) != -1 && tty_pgrp(TASK_TTY(task)) == task->pgrp)
+    if (TASK_TTY(task) != -1 && tty_pgrp(TASK_TTY(task),task->tty) == task->pgrp)
 	*p++ = '+';
     *p = '\0';
     return(buf);
@@ -107,7 +107,7 @@ get_mem_info(struct task_struct *task)
 #endif
     unsigned long ptbl;
     int size=0;
-    int tpag = task->mm->end_code / PAGE_SIZE;
+    int tpag = task->mm[0].end_code / PAGE_SIZE;
     unsigned map_nr;
     static struct mem_info mi;
 
@@ -122,7 +122,7 @@ get_mem_info(struct task_struct *task)
 	return &mi;
     pagedir = KPTR(task->tss.cr3);
 #else
-    if (kmemread(pagedir, task->tss.cr3 + (task->mm->start_code >> 20),
+    if (kmemread(pagedir, task->tss.cr3 + (task->mm[0].start_code >> 20),
 	    sizeof pagedir) < 0)
 	return &mi;
 #endif
@@ -182,19 +182,14 @@ get_mem_info(struct task_struct *task)
 }
 
 int
-tty_pgrp(int tty)
+tty_pgrp(int tty, struct tty_struct *tt)
 {
     static long tpgid[256];
-    static unsigned long _tty_table;
-    struct tty_struct *tt;
 
     if (tty == -1)
 	return -1;
     tty = minor(tty);
     if (tpgid[tty] == 0) {
-	if (!_tty_table)
-	    _tty_table = k_addr("_tty_table");
-	tt = (struct tty_struct *) get_kword(_tty_table + 4*tty);
 	kmemread(tpgid + tty, (unsigned long) &tt->pgrp, sizeof(tt->pgrp));
     }
     return tpgid[tty];
