@@ -80,11 +80,11 @@ setsize(int i)
 int
 main(int argc, char *argv[])
 {
-    int lines, row, col=0, i, opt;
-    volatile int min_scale = 6, bgnd_mode = 0, scale_shift;
-    volatile int delay = 5;
+    int row, col=0, i, opt, bgnd_mode = 0;
+    int lines, min_scale = 6, scale_shift;
+    int delay = 5;
     unsigned long av[3], _aver, _fg_console;
-    volatile int tload_console = 0;
+    int tload_console = 0;
 
 
     while ((opt = getopt(argc, argv, "bs:d:")) != -1)
