@@ -23,6 +23,7 @@
 #include <sys/resource.h>
 #include <sys/ioctl.h>
 #include <linux/sched.h>
+#include <linux/tty.h>
 #include "ps.h"
 #include "psdata.h"
 
@@ -567,7 +568,7 @@ do_it(struct task_struct *task, reg_t *stack, int num)
 		pmem = mi->pmem;
 	}
 	else
-		pmem = task->mm->rss * 1000 / nr_pages;
+		pmem = task->mm[0].rss * 1000 / nr_pages;
 	if (pcpu > 999)
 		pcpu = 999;
 	Idle -= pcpu;
@@ -610,10 +611,10 @@ do_it(struct task_struct *task, reg_t *stack, int num)
 			sprintf(tmp, "%3ld ", PZERO - task->priority);
 			break;
 		case P_PAGEIN:
-			sprintf(tmp, "%6ld ", task->mm->maj_flt);
+			sprintf(tmp, "%6ld ", task->mm[0].maj_flt);
 			break;
 		case P_TSIZ:
-			sprintf(tmp, "%5ld ", task->mm->end_code / 1024);
+			sprintf(tmp, "%5ld ", task->mm[0].end_code / 1024);
 			break;
 		case P_DSIZ:
 			sprintf(tmp, "%5ld ", SIZE(task, stack));
@@ -640,7 +641,7 @@ do_it(struct task_struct *task, reg_t *stack, int num)
 			sprintf(tmp, "%3d ", mi->dirt);
 			break;
 		case P_RSS:
-			sprintf(tmp, "%4ld ", task->mm->rss * 4);
+			sprintf(tmp, "%4ld ", task->mm[0].rss * 4);
 			break;
 		case P_WCHAN:
 			sprintf(tmp, "%-9.9s ",
