@@ -265,19 +265,16 @@ main(int argc, char *argv[])
 
 	while ((p = kvm_nextproc()) != NULL) {
 		long tpgid;
-		struct tty_struct *tt;
 
-		if (p->state == TASK_ZOMBIE || p->tty == -1) {
+		if (p->state == TASK_ZOMBIE || p->tty == NULL) {
 			free(p);
 			continue;
 		}
 		for (ep = ehead; ep != NULL; ep = ep->next) {
-			if (minor(ep->tdev) == minor(p->tty)) {
+			if (minor(ep->tdev) == minor(tty_kmemread(p->tty))) {
 				ep->jcpu += p->utime + p->stime +
 					p->cutime + p->cstime;
-				tt = (struct tty_struct *) get_kword(k_addr("_tty_table")
-					+ 4 * minor(p->tty));
-				kmemread(&tpgid, (unsigned long) &tt->pgrp,
+				kmemread(&tpgid, (unsigned long) &p->tty->pgrp,
 					 sizeof(tpgid));
 				if (p->pgrp == tpgid) {
 					/*
